from typing import Dict, List

from cimgraph.models.distributed_model import DistributedModel
from cimgraph.models.model_parsers import (add_to_catalog,
                                           add_to_typed_catalog,
                                           get_all_by_type)
from cimgraph.models.secondary_area import SecondaryArea
from cimgraph.models.switch_area import SwitchArea
